
class ScoreProcessorOverloaded(RuntimeError):
    pass


class TimeoutError(RuntimeError):
    pass


class MissingContext(RuntimeError):
    pass


class MissingModels(RuntimeError):
    pass


class TooManyRequestsError(RuntimeError):
    pass
