<html>
<head>
	<title>Objective Revision Evaluation Service</title>
	<link rel="stylesheet" href="/static/lib/wmui-style-guide.min.css">
	<link rel="stylesheet" href="/static/css/ores-site-specific.css">
	<meta name="description" content="The Objective Revision Evaluation Service (ORES) is a web service that provides machine learning as a service for Wikimedia Projects"/>
	<meta property="og:image" content="https://ores.wikimedia.org/static/images/ores_logo.svg"/>
	<style type="text/css">
		.notice {
			border: 1px solid #b32424;
			margin: 4px 2em;
			background: #fee7e6;
			padding: 0.25em 0.9em;
		}
		/**
		 * wikitable class for skinning normal tables
		 * keep in sync with commonPrint.css
		 */
		table.wikitable {
			margin: 1em 0;
			background-color: #f8f9fa;
			border: 1px solid #a2a9b1;
			border-collapse: collapse;
			color: #000;
		}

		table.wikitable > tr > th,
		table.wikitable > tr > td,
		table.wikitable > * > tr > th,
		table.wikitable > * > tr > td {
			border: 1px solid #a2a9b1;
			padding: 0.2em 0.4em;
		}

		table.wikitable > tr > th,
		table.wikitable > * > tr > th {
			background-color: #eaecf0;
			text-align: center;
		}

		table.wikitable > caption {
			font-weight: bold;
		}

		td.component {
			font-weight: bold;
		}
	</style>
</head>
<body class="page--home">
	<header id="header" class="header" role="banner">
		<div class="content-box"><h1>Versions</h1></div>
	</header>
	<div class="page">
		<div class="content-box">
			<table class="wikitable">
				<tr><th class="component">component</th><th class="version">version</th></tr>
				{% for component, version in versions.items() %}
				<tr><td class="component">{{ component }}</td><td class="version">{{ version }}</td></tr>
				{% endfor %}
			</table>
		</div>
	</div>
</body>
</html>
